using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixUserManager.Class;
using Microsoft.Win32;

namespace PhoenixUserManager.GUI
{
    public partial class fr_AddReport : Form
    {
        #region Variables
        /// <summary>
        /// Information about the new user
        /// </summary>
        private UserManager vUserManager =
            new UserManager("PhoenixUserManag", "", "jibedoubleve.mine.nu", "Phoenix", "Phoenix");
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_AddReport()
        {
            InitializeComponent();
        }
        #endregion

        #region Methods
        /// <summary>
        /// Gets the user id which is on the Registry
        /// </summary>
        /// <param name="_UserID">The returned User ID</param>
        /// <returns>TRUE if the calue was found otherwise FALSE</returns>
        private bool GetUserID(ref int _UserID)
        {
            try
            {
                _UserID = UserManager.GetIDInRegistry(this.vUserManager.Software);
                return true;
            }
            catch (ArgumentException) { return false; }
        }
        #endregion

        #region Events
        private void Event_FrameLoad(object sender, EventArgs e)
        {
            int UserID = 0;
            if (!GetUserID(ref UserID))
            {
                DialogResult dr = MessageBox.Show("Vous n'tes pas inscrit dans notre base de donnes! Pour envoyer"
                    + " un rapport, il faut tre inscrit. S'inscrire?", "Question", MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question);
                if (dr == DialogResult.No) this.Close();
                fr_Inscription fr = new fr_Inscription();
                dr = fr.ShowDialog();
                if (dr == DialogResult.Cancel) return;

                if (!GetUserID(ref UserID))
                    MessageBox.Show("Votre identifiant est erron. Impossible de crer un rapport!");
                vUserManager.Fill(UserID);
            }
            else
            {
                try
                {
                    vUserManager.Fill(UserID);
                    this.Text += " (" + vUserManager.Name + " " + vUserManager.Surname + ")";
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                }
            }
        }
        /// <summary>
        /// Send the report
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Send(object sender, EventArgs e)
        {
            try
            {
                string _Message = "Veuillez:";
                bool OK = true;
                if (this.vUserManager.UserID == -1) return;
                if (this.tb_Title.Text == "")
                {
                    OK = false;
                    _Message += "\r\nAjouter un titre au rapport";
                }
                if (this.tb_Message.Text == "")
                {
                    OK = false;
                    _Message += "\r\nAjouter un message au rapport";
                }

                if (!OK)
                {
                    MessageBox.Show(_Message, "Attention", MessageBoxButtons.OK, MessageBoxIcon.Asterisk);
                    return;
                }
                this.vUserManager.AddReport(vUserManager.UserID, this.tb_Title.Text, this.tb_Message.Text);
                this.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show("Impossible d'ajouter le rapport! (" + ex.Message + ")",
                    "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        /// <summary>
        /// List the logs of a user
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_ListLog(object sender, EventArgs e)
        {
            fr_SearchLog fr = new fr_SearchLog();
            fr.UserManager = this.vUserManager;
            fr.ShowDialog();
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the UserManager which manager the user inscription
        /// </summary>
        public UserManager UserManager
        {
            get { return vUserManager; }
            set { vUserManager = value; }
        }
        #endregion
    }
}